<div align="center">
# Quant Tools
</div>

-----

## 如何安装？

```bash
pip install wisecon
```

-----

<div align="center">

> Wechat

<center>
<img src="https://raw.githubusercontent.com/zlai-llm/zlai/master/assets/wechat.jpg" width="160px">
<h5>微信群</h5>
</center>

</div>

-----
@2024/03/27
